@@ -382,14 +382,14 @@ def gsselect(target, ra, dec, pa=0.0, wfs='OIWFS', ifu='none',
     # long = [-155.46905, -70.736694]
     # elev = [4213., 2722.]
 
-    if 'n' in site.lower() or "mko" in site.lower():
-        l_site = 'N'
-        isite = 0
-        # utcoffset = 10.0 * u.hour
-    elif 's' in site.lower() or "cpo" in site.lower():
+    if 's' in site.lower() or "cpo" in site.lower():
         l_site = 'S'
         isite = 1
         # utcoffset = -4.0 * u.hour + dst * u.hour
+    elif 'n' in site.lower() or "mko" in site.lower():
+        l_site = 'N'
+        isite = 0
+        # utcoffset = 10.0 * u.hour
     else:
         print('Site must be "cpo" or "mko" or include a "S" or "N".')
         return
@@ -545,14 +545,16 @@ def gsselect(target, ra, dec, pa=0.0, wfs='OIWFS', ifu='none',
         if overwrite or not os.path.exists(gsfile):
             if os.path.exists(gsfile):
                 os.remove(gsfile)
-            gsres = gemgstable(l_ra, l_dec, gsfile, cat='ucac4', radius=0.12, site='cpo')
-        gsq = parse_single_table(gsfile).to_table(use_names_over_ids=True)
-        id = gsq['ucac4']
-        gscoo = SkyCoord(gsq['raj2000'], gsq['dej2000'], frame='icrs', unit=(u.deg, u.deg))
-        if l_inst == 'GNIRS' and l_wfs == 'OIWFS':
-            mag = gsq['kmag']
-        else:
-            mag = gsq['fmag']
+            gsres = gemgstable(l_ra, l_dec, gsfile, cat='ucac4', radius=0.12, site='mko')
+        id = []
+        if os.path.exists(gsfile):
+            gsq = parse_single_table(gsfile).to_table(use_names_over_ids=True)
+            id = gsq['ucac4']
+            gscoo = SkyCoord(gsq['raj2000'], gsq['dej2000'], frame='icrs', unit=(u.deg, u.deg))
+            if l_inst == 'GNIRS' and l_wfs == 'OIWFS':
+                mag = gsq['kmag']
+            else:
+                mag = gsq['fmag']
 
     nquery = len(id)
     if nquery < 1:
